@@ -30,7 +30,7 @@
 /** constructor of class task */
 Task::Task()
 {
-    srand(time(NULL));
+    qsrand(time(NULL));
 #ifdef DEBUG
     qDebug() << "constructor task";
 #endif
@@ -421,7 +421,7 @@ unsigned short Task::make_operation(short padd_add, short padd_div, short padd_m
             op_vector.push_back(SUB);
     } else {
         do {
-            operations = short((double(rand()) / RAND_MAX) * 4);
+            operations = short((double(qrand()) / RAND_MAX) * 4);
             switch (operations) {
             case ADD:
                 if (padd_add == YES) {
@@ -498,7 +498,7 @@ int Task::make_main_dn(unsigned int pmax_md, unsigned short max_product_length)
     /* find a main denominator in the given limits by pmax_md and check
      * if the main denominator has enough prime factors */
     do {
-        denominator = int (((double(rand()) / RAND_MAX) * pmax_md) + 1);
+        denominator = int (((double(qrand()) / RAND_MAX) * pmax_md) + 1);
     } while ((pmax_md < 1) ||
              (prim_factor_nr(denominator) < max_product_length));
 
@@ -553,7 +553,7 @@ void Task::make_numerators(int main_denominator, short pnr_ratios)
 
     /* add a new ratio to the task and compute the numerator randomly */
     for (short tmpcounter = 0; tmpcounter < pnr_ratios; tmpcounter++) {
-        (*this).add_ratio(int ((double(rand()) / RAND_MAX)
+        (*this).add_ratio(int ((double(qrand()) / RAND_MAX)
                                * max_numerator) + 1, 1);
     }
     return;
@@ -588,7 +588,7 @@ void Task::make_denominators(int main_denominator, short pmax_md,
     for (ratio_pointer = ratio_vector.begin();
             ratio_pointer != ratio_vector.end(); ++ratio_pointer) {
         do {
-            tmp_deno = int ((double(rand()) / RAND_MAX) * pmax_md) + 1;
+            tmp_deno = int ((double(qrand()) / RAND_MAX) * pmax_md) + 1;
         } while (main_denominator % tmp_deno != 0);
         (*ratio_pointer).setDenominator(tmp_deno);
     }
@@ -617,7 +617,7 @@ void Task::make_denominators(int main_denominator, short pmax_md,
                     /* the prim_fac_vector is sorted, but we do not want the
                      * factors in this sorted way as our denominators;
                      * so we choose one randomly */
-                    next_fac = (unsigned short)((double(rand()) / RAND_MAX)
+                    next_fac = (unsigned short)((double(qrand()) / RAND_MAX)
                                                 * unused_fac);
                     tmp_counter = 0;
 
@@ -652,7 +652,7 @@ void Task::make_denominators(int main_denominator, short pmax_md,
                     /* the prim_fac_vector is sorted, but we do not want the
                      * factors in this sorted way as our denominators;
                      * so we choose one randomly */
-                    next_fac = (unsigned short)((double(rand()) / RAND_MAX)
+                    next_fac = (unsigned short)((double(qrand()) / RAND_MAX)
                                                 * unused_fac);
                     tmp_counter = 0;
 
